Figures from Distinct methane-dependent biogeochemical regimes in Arctic
seafloor gas hydrate mounds
================
Scott Klasek
11-11-20

## import figures generated by previous files:

``` r
# this chunk imports figures that have been exported from other documents into /figures
figure2 <- readRDS(file = "/Users/scottklasek/Desktop/svalflux/figures/figure2") 
figure3 <- readRDS(file = "/Users/scottklasek/Desktop/svalflux/figures/figure3") 
figure4 <- readRDS(file = "/Users/scottklasek/Desktop/svalflux/figures/figure4") 
figure5 <- readRDS(file = "/Users/scottklasek/Desktop/svalflux/figures/figure5") # biomarkers
figure6 <- readRDS(file = "/Users/scottklasek/Desktop/svalflux/figures/figure6") # alpha diversity 
ord1.p.stage <- readRDS(file = "/Users/scottklasek/Desktop/svalflux/figures/ord1.p.stage") # figure 7A ordination
ord1.p.zone <- readRDS(file = "/Users/scottklasek/Desktop/svalflux/figures/ord1.p.zone") # figure 7B ordination
```

## Figure 1: Map of study area

[In case the link doesn’t work, try
here](https://github.com/sklasek/svalflux/blob/master/figures/F1.png)

``` r
knitr::include_graphics("/Users/scottklasek/Desktop/svalflux/figures/F1.png")
```

<img src="/Users/scottklasek/Desktop/svalflux/figures/F1.png" width="900" />

Figure 1. Bathymetric map of Storfjordrenna gas hydrate mounds and
modeling approach. (A) Storfjordrenna is located south of the Svalbard
Archipelago. Locations of cores and gas hydrate mounds (GHMs) are shown.
White polygons indicate areas of seafloor gas release observed at the
time of the cruise. All cores were collected from GHMs, with the
exception of the reference core GC1048, which was sampled 400 m west of
GHM5. The schematic in (B) depicts sulfate and methane concentrations
throughout a sediment column at a steady-state condition. As methane
flux increases, (C), SR-AOM is stimulated at shallower depths and
sulfate profiles show a concave-up curvature. After decades of steadily
increasing methane flux at a particular area, (D), reactive-transport
modeling can be used to estimate how quickly the methane front diffused
the distance between the current and prior sulfate depletion depths
(indicated by the orange
bracket).

## Panel figures from three methane flux regimes:

### Figure 2, steady-state cores:

<img src="5_main_figures_files/figure-gfm/unnamed-chunk-3-1.png" style="display: block; margin: auto;" />

Figure 2. Geochemical, numerical, microbial community, and gene
abundance data from four sites showing steady-state sulfate-methane
dynamics. GC1068–1070 are from GHM5, and reference core GC1048 is
located to the west of GHM5. Sulfate-methane transition depths are
indicated by dashed lines. (A) shows porewater sulfate, sulfide, and
alkalinity, and (B) present-day modeled AOM rates. (C) indicates percent
abundances of dominant bacterial and archaeal classes, dominant
anaerobic methanotrophic archaeal (ANME) familes, and sulfate-reducing
bacterial (SRB) genera.(D) shows copy numbers of mcrA and dsrAB genes
per gram bulk sediment, with values below the detectable limit (10^3
g-1) along the margin of the panel. Macroscopic translucent-to-yellow
biofilms, shown as yellow symbols in panel (A), were observed at
approximate SMT depths in cores GC1048 and GC1070 (symbol size not to
scale with depth
axis).

### Figure 3, increasing methane flux:

<img src="5_main_figures_files/figure-gfm/unnamed-chunk-4-1.png" style="display: block; margin: auto;" />

Figure 3. Geochemical, numerical, microbial community, and gene
abundance data from two sites showing sulfate-methane dynamics
suggestive of recent increases in methane flux. Gravity cores GC1045 and
GC1081 are located at GHMs 3 and 4, respectively. Sulfate-methane
transition depths are indicated by dashed lines. (A) shows porewater
sulfate, sulfide, and alkalinity, and (B) the temporal progression of
modeled AOM rates from 10 years ago to up to 2 years after sampling. (C)
indicates percent abundances of dominant bacterial and archaeal classes,
dominant anaerobic methanotrophic archaeal (ANME) familes, and
sulfate-reducing bacterial (SRB) genera. (D) shows copy numbers of mcrA
and dsrAB genes per gram bulk
sediment.

### Figure 4, active methane seepage:

<img src="5_main_figures_files/figure-gfm/unnamed-chunk-5-1.png" style="display: block; margin: auto;" />

Figure 4. Geochemical, microbial community, and gene abundance data from
an active seep site. Push core PC1029 is located at the seep in the
center of GHM3. (A) shows porewater sulfate, sulfide, and alkalinity
concentrations in addition to frenulate siboglinid tubeworms and gas
hydrate nodules several cm in diameter recovered in a replicate core at
40-50 cm below seafloor. (B) depicts percent abundances of dominant
Bacterial and Archaeal classes within the microbial community (left
panel), dominant anaerobic methanotrophic archaeal (ANME) families
(center panel) and sulfate-reducing bacterial (SRB) genera (right
panel). (C) shows log10 copy numbers of mcrA and dsrAB genes per gram
bulk
sediment.

## Figure 5, differentially abundant ASVs across zones and methane flux types:

<img src="5_main_figures_files/figure-gfm/unnamed-chunk-6-1.png" style="display: block; margin: auto;" />

Figure 5. Differentially abundant ASVs between three discrete stages of
methane dynamics, either above or below the sulfate-methane transition
zone. Higher differential abundance values represent stronger
associations between an ASV and a particular group. In addition to
position relative to the SMTZ, vertical panels convey class-level
taxonomic annotations for all taxa except ANME (at family level) and SRB
(at genus level). Bubble sizes represent mean percent abundances within
each group. Differential abundance was inferred using an alpha of 0.05
and a Benjamini-Hochberg correction for multiple
comparisons.

## Figure 6, alpha-diversity (diversity within communities):

<img src="5_main_figures_files/figure-gfm/unnamed-chunk-7-1.png" style="display: block; margin: auto;" />

Figure 6. Microbial community diversity patterns across peak modeled AOM
depths. Shannon diversity indices of microbial communities for
individual samples plotted by their distance above (positive) or below
(negative) the depths corresponding to present-day maximum AOM rates
across all cores. Cores are divided by panel based on whether methane
flux is (A) high, or (B) low, and colored according to different stages
of methane dynamics. Dotted horizontal lines show the distance interval
corresponding to high methane flux samples. Multiple R^2 and slope
p-values are shown for linear regressions of points within these
intervals.

## Figure 7, beta-diversity (diversity between communities):

The two most helpful categories that explain the most of the variance
within these microbial communities are methane stage and redox zone.
There is a significant interaction among them too.

``` r
library(patchwork)
ord1.p.stage + ord1.p.zone
```

<img src="5_main_figures_files/figure-gfm/unnamed-chunk-8-1.png" style="display: block; margin: auto;" />

Figure 7. Principal Coordinates Analysis (PCoA) ordination of weighted
Unifrac distances between all communities, colored according to stages
of methane dynamics (A), and redox zone within the sediment column (B).
A Hellinger transformation was applied to ASV count tables before
calculating the distance matrix. PERMANOVA tests verify distinct
community structures present across stages and redox zones, with R^2 and
p-values shown in corresponding plots.

## Figure 8, conceptual figure

[In case the link doesn’t work, try
here](https://github.com/sklasek/svalflux/blob/master/figures/flux.conceptual.2.png)

``` r
knitr::include_graphics("/Users/scottklasek/Desktop/svalflux/figures/flux.conceptual.2.png")
```

<img src="/Users/scottklasek/Desktop/svalflux/figures/flux.conceptual.2.png" width="2836" />

Figure 8. Conceptual depiction of microbial community changes concurrent
with distinct stages of methane dynamics at Storfjordrenna GHMs. Methane
and sulfate profiles are shown in gray and blue lines, respectively,
with microbial community changes indicated by blowup circles. ANME and
SRB represent red and green ovals, with other bacteria and archaea in
gray (shapes representing the diversity of other taxa). (A) Methane
seepage, potentially driven by dissociation of gas hydrates at the upper
limit of stability, stimulates high rates of AOM and densities of
ANME/SRB. Sulfide fluxes from AOM are sufficient to support frenulate
siboglinid tubeworms, which may irrigate sulfate over the upper several
cm of sediment, increase redox gradients in underlying sediments, and
further ANME/SRB growth. (B) In the absence of bioirrigation, a
concave-up bend in porewater sulfate suggests recent methane migration
into the sulfate-reduction zone that may have resulted from a pulse of
methane beginning around 290 years ago. Methane travels upward
throughout the sediment column, and ANME/SRB growth follows with less
than a year of lag time, driving down alpha diversity. (C) Steady-state
sulfate profiles suggest no recent methane influx, and low rates of AOM
are observed at the SMTZ. Stable conditions may allow for higher
microbial diversity and the growth of macroscopic biofilms.
